@@ -130,7 +130,8 @@ class SKLearnModel(Model):
             self.__model = LinearRegression()
         elif self.alg_id == ALG_LASSO:
             alpha = kwargs['alpha'] if 'alpha' in kwargs.keys() else 0.1
-            self.__model = Lasso(alpha=alpha)
+            max_iter = kwargs['max_iter'] if 'max_iter' in kwargs.keys() else 1000
+            self.__model = Lasso(alpha=alpha, max_iter=max_iter)
         elif self.alg_id == ALG_DCTR:
             self.__model = DecisionTreeRegressor()
         elif self.alg_id == ALG_SYMR:
@@ -145,10 +146,12 @@ class SKLearnModel(Model):
                                              p_point_mutation=p_point_mutation, verbose=verbose)
         elif self.alg_id == ALG_KRR:
             alpha = kwargs['alpha'] if 'alpha' in kwargs.keys() else 1.0
-            self.__model = KernelRidge(alpha=alpha)
+            degree = kwargs['degree'] if 'degree' in kwargs.keys() else 3
+            self.__model = KernelRidge(alpha=alpha, kernel='poly', degree=degree)
         elif self.alg_id == ALG_KNNR:
             n_neighbors = kwargs['n_neighbors'] if 'n_neighbors' in kwargs.keys() else 5
-            self.__model = KNeighborsRegressor(n_neighbors=n_neighbors)
+            p = kwargs['p'] if 'p' in kwargs.keys() else 2
+            self.__model = KNeighborsRegressor(n_neighbors=n_neighbors, p=p)
         elif self.alg_id == ALG_GPR:
             kernel = DotProduct() + WhiteKernel()
             self.__model = GaussianProcessRegressor(kernel=kernel, alpha=1e-8)
